@@ -1,6 +1,6 @@
 package Test::Mojo::Role::Log;
 use Mojo::Base -role, -signatures;
-our $VERSION = '0.2.0';
+our $VERSION = '0.2.1';
 
 around 'new' => sub {
     my $orig = shift;
@@ -142,7 +142,7 @@ Points to an array with all the log messages issued since the last request.
 
 =head1 METHODS
  
-The role L<Test::Mojo::Role::Log> adds following new methods to L<Test::Mojo> ones.
+The role L<Test::Mojo::Role::Log> adds the following new methods to L<Test::Mojo> ones.
  
 =head2 log_like($rx,$desc)
 
@@ -152,6 +152,10 @@ The role L<Test::Mojo::Role::Log> adds following new methods to L<Test::Mojo> on
 Check if the given log message has been issued. All the log messages issued since the start of the current request will get checked.
 If $logLevel is set to undef the logLevel does not get checked.
 
+=head2 log_trace_like($rx,$desc)  (if mojo supports it)
+ 
+Find a trace level log message matching the given $rx.
+
 =head2 log_debug_like($rx,$desc)
  
 Find a debug level log message matching the given $rx.
@@ -175,6 +179,7 @@ Find a fatal level log message matching the given $rx.
 =head2 *_unlike
 
 For each of the methods above there is ac coresponding
+
 =head1 AUTHOR
 
 Tobias Oetiker E<lt>tobi@oetiker.chE<gt>
